@@ -4,17 +4,35 @@ use warnings;
 
 package Dist::Zilla::Plugin::Test::MinimumVersion;
 # ABSTRACT: Release tests for minimum required versions
-our $VERSION = '2.000002'; # VERSION
+our $VERSION = '2.000003'; # VERSION
+
 use Moose;
 extends 'Dist::Zilla::Plugin::InlineFiles';
+with 'Dist::Zilla::Role::TextTemplate';
+
+has max_target_perl => (
+    is => 'ro',
+    isa => 'Str',
+    predicate => 'has_max_target_perl',
+);
+
+around add_file => sub {
+    my ($orig, $self, $file) = @_;
+    $self->$orig(
+        Dist::Zilla::File::InMemory->new({
+            name => $file->name,
+            content => $self->fill_in_string(
+                $file->content,
+                { (version => $self->max_target_perl)x!!$self->has_max_target_perl }
+            ),
+        })
+    );
+};
 
 __PACKAGE__->meta->make_immutable;
 no Moose;
 1;
 
-
-
-
 =pod
 
 =encoding utf-8
@@ -25,21 +43,27 @@ Dist::Zilla::Plugin::Test::MinimumVersion - Release tests for minimum required v
 
 =head1 VERSION
 
-version 2.000002
+version 2.000003
 
 =head1 SYNOPSIS
 
 In C<dist.ini>:
 
     [Test::MinimumVersion]
+    max_target_perl = 5.10.1
 
 =head1 DESCRIPTION
 
-This is an extension of L<Dist::Zilla::Plugin::InlineFiles>, providing the
-following file:
+This is an extension of L<Dist::Zilla::Plugin::InlineFiles>, providing a
+L<Test::MinimumVersion> test:
 
   xt/release/minimum-version.t - a standard Test::MinimumVersion test
 
+You should provide the highest perl version you want to require as
+C<target_max_version>. If you accidentally use perl features that are newer
+than that version number, then the test will fail, and you can go change
+whatever bumped up the minimum perl version required.
+
 =for test_synopsis 1;
 __END__
 
@@ -84,7 +108,6 @@ the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-
 __DATA__
 ___[ xt/release/minimum-version.t ]___
 #!perl
@@ -94,4 +117,7 @@ use Test::More;
 eval "use Test::MinimumVersion";
 plan skip_all => "Test::MinimumVersion required for testing minimum versions"
   if $@;
-all_minimum_version_from_metayml_ok();
+{{ $version
+    ? "all_minimum_version_ok( qq{$version} );"
+    : "all_minimum_version_from_metayml_ok();"
+}}
